@@ -24,3 +24,14 @@ class AccessDenied(MWSError):
 class SignatureDoesNotMatch(MWSError):
     """The signature used does not match the server's
     calculated signature value."""
+    pass
+
+
+class QuotaExceeded(MWSError):
+    """The total number of requests in an hour was exceeded."""
+    pass
+
+
+class RequestThrottled(MWSError):
+    """The frequency of requests was greater than allowed.."""
+    pass
